@@ -30,7 +30,6 @@ from functools import partial
 from tornado.curl_httpclient import CurlAsyncHTTPClient
 from tornado.ioloop import IOLoop
 
-COOKIE_FILE = ".cookie_jar"
 
 class TornadoHTTPClient(CurlAsyncHTTPClient):
     def initialize(self, *args, **kwargs):
@@ -65,8 +64,8 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
     def wrap_prepare_curl_callback(self, callback):
         def _wrap_prepare_curl_callback(curl):
             if self.use_cookie:
-                curl.setopt(pycurl.COOKIEFILE, COOKIE_FILE)
-                curl.setopt(pycurl.COOKIEJAR, COOKIE_FILE)
+                curl.setopt(pycurl.COOKIEFILE, "")
+                #curl.setopt(pycurl.COOKIEJAR, "")
 
             if not self.verify_ssl:
                 curl.setopt(pycurl.SSL_VERIFYPEER, 0)
